pub enum PlaceholderKind {
Show 17 variants
Title,
Body,
CenterTitle,
Subtitle,
DateTime,
SlideNumber,
Footer,
Header,
Object,
Chart,
Table,
ClipArt,
Diagram,
Media,
Picture,
SlideImage,
Other,
}Expand description
ST_PlaceholderType (19.7.10).
Variants
Title
Body
CenterTitle
Subtitle
DateTime
SlideNumber
Header
Object
Chart
Table
ClipArt
Diagram
Media
Picture
SlideImage
Other
Implementations
Sourceimpl PlaceholderKind
impl PlaceholderKind
pub fn parse(value: &[u8]) -> PlaceholderKind
Sourcepub fn is_furniture(self) -> bool
pub fn is_furniture(self) -> bool
True for the date, footer and slide number placeholders, whose text is presentation furniture rather than slide content.
pub fn as_str(self) -> &'static str