pub struct Picture {
pub embed: Option<String>,
pub link: Option<String>,
pub media: Option<String>,
}Expand description
A picture’s image reference (20.1.8.13).
Fields
embed: Option<String>r:embed: relationship id of an image part in the package.
link: Option<String>r:link: relationship id of an external image.
media: Option<String>Relationship id of an attached audio or video clip.