pub enum Event<'a> {
Start(Start<'a>),
End(Name<'a>),
Text {
raw: &'a [u8],
cdata: bool,
},
Eof,
}Expand description
One token of the document.
Variants
Start(Start<'a>)
End(Name<'a>)
An end tag, or the synthesized end of a self-closing element.
Text
Character data, still escaped unless it came from a CDATA section.
Eof