pub struct Entry {
pub name: String,
pub raw_name: Vec<u8>,
pub method: u16,
pub flags: u16,
pub version_needed: u16,
pub crc32: u32,
pub compressed_size: u64,
pub uncompressed_size: u64,
pub header_offset: u64,
pub central_offset: u64,
pub extra_ids: Vec<u16>,
pub has_comment: bool,
}Expand description
One item of the central directory, exactly as recorded.
Fields
name: StringThe item name decoded as UTF-8, with invalid sequences replaced.
raw_name: Vec<u8>The item name bytes as written.
method: u16flags: u16version_needed: u16crc32: u32compressed_size: u64uncompressed_size: u64header_offset: u64Local header offset as recorded (before any shift the archive needed).
central_offset: u64Offset of this entry’s central directory header.
extra_ids: Vec<u16>Header ids of the extra fields present in the central header.
has_comment: boolTrue when the central header’s comment length was nonzero.
Implementations
Sourceimpl Entry
impl Entry
pub fn is_directory(&self) -> bool
pub fn is_encrypted(&self) -> bool
pub fn has_data_descriptor(&self) -> bool
pub fn names_are_utf8(&self) -> bool
pub fn has_zip64_extra(&self) -> bool